import { type CollectionReference } from '@google-cloud/firestore';
import { type KeyValueCache } from '@apollo/utils.keyvaluecache';
import DataLoader from 'dataloader';
import { type FirestoreDataSourceOptions } from './datasource';
export interface createCatchingMethodArgs<DType> {
    collection: CollectionReference<DType>;
    cache: KeyValueCache;
    options?: FirestoreDataSourceOptions;
}
export interface FindArgs {
    ttl?: number;
}
export interface CachedMethods<DType> {
    findOneById: (id: string, args?: FindArgs) => Promise<DType | undefined>;
    findManyByIds: (ids: string[], args?: FindArgs) => Promise<Array<DType | undefined>>;
    deleteFromCacheById: (id: string) => Promise<void>;
    dataLoader?: DataLoader<string, DType, string>;
    cache?: KeyValueCache;
    cachePrefix?: string;
    primeLoader: (item: DType | DType[], ttl?: number) => void | Promise<void>;
    reviver: (key: string | number, value: any) => any;
    replacer: (key: string | number, value: any) => string;
}
export declare const createCachingMethods: <DType extends {
    id: string;
}>({ collection, cache, options }: createCatchingMethodArgs<DType>) => CachedMethods<DType>;
